@@ -5,7 +5,7 @@ The module contains a single class, `MassFunction`, which wraps almost all the
 functionality of :mod:`hmf` in an easy-to-use way.
 '''
 
-version = '1.4.5'
+version = '1.4.6'
 
 ###############################################################################
 # Some Imports
@@ -15,12 +15,16 @@ import scipy.integrate as intg
 import numpy as np
 from numpy import sin, cos, tan, abs, arctan, arccos, arcsin, exp
 import copy
-
+import logging
 import cosmolopy as cp
 import tools
 from fitting_functions import Fits
 from transfer import Transfer
 
+#===============================================================================
+# Logger
+#===============================================================================
+logger = logging.getLogger('hmf')
 class MassFunction(object):
     """
     An object containing all relevant quantities for the mass function.
@@ -45,7 +49,7 @@ class MassFunction(object):
     M : array_like, optional, default ``np.linspace(10,15,501)``
         The masses at which to perform analysis [units :math:`\log_{10}M_\odot h^{-1}`]. 
                      
-    mf_fit : str, optional, default ``"SMT"``
+    mf_fit : str or callable, optional, default ``"SMT"``
         A string indicating which fitting function to use for :math:`f(\sigma)`
                        
         Available options:
@@ -66,7 +70,10 @@ class MassFunction(object):
         #. ``'Angulo_Bound'``: Angulo sub-halo function 2012
         #. ``'Bhattacharya'``: Bhattacharya empirical fit 2011
         #. ``'Behroozi'``: Behroozi extension to Tinker for high-z 2013
-        #. ``'user_model'``: A user-input string function
+
+        Alternatively, one may define a callable function, with the signature
+        ``func(self)``, where ``self`` is a :class:`MassFunction` object (and
+        has access to all its attributes). This may be passed here. 
         
     delta_wrt : str, {``"mean"``, ``"crit"``}
         Defines what the overdensity of a halo is with respect to, mean density
@@ -96,8 +103,8 @@ class MassFunction(object):
 
 
     def __init__(self, M=None, mf_fit="ST", delta_h=200.0,
-                 delta_wrt='mean', user_fit='', cut_fit=True, z2=None, nz=None,
-                 delta_c=1.686, **kwargs):
+                 delta_wrt='mean', cut_fit=True, z2=None, nz=None,
+                 delta_c=1.686, mv_scheme="trapz", **kwargs):
         """
         Initializes some parameters      
         """
@@ -118,20 +125,21 @@ class MassFunction(object):
         self.M = M
         self.delta_h = delta_h
         self.delta_wrt = delta_wrt
-        self.user_fit = user_fit
         self.cut_fit = cut_fit
         self.z2 = z2
         self.nz = nz
         self.delta_c = delta_c
         self.transfer = Transfer(**kwargs)
+        self.mv_scheme = mv_scheme
 
+        tools.check_kr(self.M[0], self.M[-1], self.cosmo.mean_dens,
+                       self.transfer.lnk[0], self.transfer.lnk[-1])
     def update(self, **kwargs):
         """
         Update the class with the given arguments in an optimal manner.
         
         Accepts any argument that the constructor takes.
         """
-        # Now do rest of the parameters
         for key, val in kwargs.iteritems():
 
 #             The following takes care of everything specifically in this class
@@ -158,6 +166,8 @@ class MassFunction(object):
         # The rest are sent to the Transfer class (stupid values weeded out there)
         self.transfer.update(**the_rest)
 
+        tools.check_kr(self.M[0], self.M[-1], self.cosmo.mean_dens,
+                       self.transfer.lnk[0], self.transfer.lnk[-1])
     # --- SET PROPERTIES -------------------------------------------------------
     @property
     def M(self):
@@ -197,20 +207,36 @@ class MassFunction(object):
         self.__delta_c = val
 
         del self.fsigma
+
+    @property
+    def mv_scheme(self):
+        return self.__mv_scheme
+
+    @mv_scheme.setter
+    def mv_scheme(self, val):
+        if val not in ['trapz', 'simps', 'romb']:
+            raise ValueError("mv_scheme wrong")
+        else:
+            self.__mv_scheme = val
+            del self._sigma_0
+
     @property
     def mf_fit(self):
         return self.__mf_fit
 
     @mf_fit.setter
     def mf_fit(self, val):
-
+        # mf_fit may be a callable or a string. Try callable first.
         try:
-            val = str(val)
+            val(self)
         except:
-            raise ValueError("mf_fit must be a string, got ", val)
+            try:
+                val = str(val)
+            except:
+                raise ValueError("mf_fit must be a string or callable, got ", val)
 
-        if val not in Fits.mf_fits + ["Behroozi"]:
-            raise ValueError("mf_fit is not in the list of available fitting functions: ", val)
+            if val not in Fits.mf_fits + ["Behroozi"]:
+                raise ValueError("mf_fit is not in the list of available fitting functions: ", val)
 
         # Also delete stuff dependent on it
         del self.fsigma
@@ -295,16 +321,6 @@ class MassFunction(object):
 
         del self.dndm
 
-    @property
-    def user_fit(self):
-        return self.__user_fit
-
-    @user_fit.setter
-    def user_fit(self, val):
-        self.__user_fit = val
-
-        del self.fsigma
-
     @property
     def cut_fit(self):
         return self.__cut_fit
@@ -334,8 +350,6 @@ class MassFunction(object):
                 self.__delta_halo = self.delta_h
 
             elif self.delta_wrt == 'crit':
-                print cp.density.omega_M_z(self.transfer.z, **self.cosmo.cosmolopy_dict())
-                print self.cosmo.cosmolopy_dict()
                 self.__delta_halo = self.delta_h / cp.density.omega_M_z(self.transfer.z, **self.cosmo.cosmolopy_dict())
             return self.__delta_halo
 
@@ -364,7 +378,8 @@ class MassFunction(object):
         except:
             self.__sigma_0 = tools.mass_variance(self.M, self.transfer._lnP_0,
                                                  self.transfer.lnk,
-                                                 self.cosmo.mean_dens)
+                                                 self.cosmo.mean_dens,
+                                                 self.mv_scheme)
             return self.__sigma_0
 
     @_sigma_0.deleter
@@ -469,15 +484,21 @@ class MassFunction(object):
         try:
             return self.__fsigma
         except:
-            fits_class = Fits(self, self.cut_fit)
-            self.__fsigma = fits_class.nufnu()
+            try:
+                self.__fsigma = self.mf_fit(self)
+            except:
+                fits_class = Fits(self)
+                self.__fsigma = fits_class.nufnu()
 
             if np.sum(np.isnan(self.__fsigma)) > 0.8 * len(self.__fsigma):
                 # the input mass range is almost completely outside the cut
-                self.massrange_error = "The specified mass-range was almost entirely outside of the limits from the fit. Ignored fit range..."
+                logger.warning("The specified mass-range was almost entirely \
+                                outside of the limits from the fit. Ignored fit range...")
                 self.cut_fit = False
-                fits_class.cut_fit = False
-                self.__fsigma = fits_class.nufnu()
+                try:
+                    self.__fsigma = self.mf_fit(self)
+                except:
+                    self.__fsigma = fits_class.nufnu()
 
             return self.__fsigma
 
