@@ -15,6 +15,9 @@ import collections
 import cosmolopy as cp
 import itertools
 
+import logging
+
+logger = logging.getLogger('hmf')
 #===============================================================================
 # Functions
 #===============================================================================
@@ -28,39 +31,14 @@ def check_kr(min_m, max_m, mean_dens, mink, maxk):
     
     See http://arxiv.org/abs/1306.6721 for details. 
     """
-    # Define mass from radius function
-    def M(r):
-        return 4 * np.pi * r ** 3 * mean_dens / 3
-
     # Define min and max radius
-    min_r = (3 * min_m / (4 * np.pi * mean_dens)) ** (1. / 3.)
-    max_r = (3 * max_m / (4 * np.pi * mean_dens)) ** (1. / 3.)
+    min_r = mass_to_radius(min_m, mean_dens)
+    max_r = mass_to_radius(max_m, mean_dens)
 
-    errmsg1 = \
-"""
-Please make sure the product of minimum radius and maximum k is > 3.
-If it is not, then the mass variance could be extremely inaccurate.
-                    
-"""
-
-    errmsg2 = \
-"""
-Please make sure the product of maximum radius and minimum k is < 0.1
-If it is not, then the mass variance could be inaccurate.
-                    
-"""
-
-    if maxk * min_r < 3:
-        error1 = errmsg1 + "This means extrapolating k to " + str(3 / min_r) + " or using min_M > " + str(np.log10(M(3.0 / maxk)))
-    else:
-        error1 = None
-
-    if mink * max_r > 0.1:
-        error2 = errmsg2 + "This means extrapolating k to " + str(0.1 / max_r) + " or using max_M < " + str(np.log10(M(0.1 / mink)))
-    else:
-        error2 = None
-
-    return error1, error2
+    if np.exp(maxk) * min_r < 3:
+        logger.warn("r_min (%s) * k_max (%s) < 3. Mass variance could be inaccurate." % (min_r, np.exp(maxk)))
+    elif np.exp(mink) * max_r > 0.1:
+        logger.warn("r_max (%s) * k_min (%s) > 0.1. Mass variance could be inaccurate." % (max_r, np.exp(mink)))
 
 def normalize(norm_sigma_8, unn_power, lnk, mean_dens):
     """
@@ -103,7 +81,7 @@ def normalize(norm_sigma_8, unn_power, lnk, mean_dens):
 
     return power, normalization
 
-def mass_variance(M, power, lnk, mean_dens):
+def mass_variance(M, power, lnk, mean_dens, scheme='trapz'):
     """
     Calculate the mass variance, :math:`\sigma(M)` using the top-hat window function.
     
@@ -139,8 +117,12 @@ def mass_variance(M, power, lnk, mean_dens):
     rest = np.exp(power + 3 * lnk)
     for i, m in enumerate(M):
         integ = rest * top_hat_window(m, lnk, mean_dens)
-        sigma[i] = (0.5 / np.pi ** 2) * intg.trapz(integ, dx=dlnk)
-
+        if scheme == 'trapz':
+            sigma[i] = (0.5 / np.pi ** 2) * intg.trapz(integ, dx=dlnk)
+        elif scheme == "simps":
+            sigma[i] = (0.5 / np.pi ** 2) * intg.simps(integ, dx=dlnk)
+        elif scheme == 'romb':
+            sigma[i] = (0.5 / np.pi ** 2) * intg.romb(integ, dx=dlnk)
     return np.sqrt(sigma)
 
 def top_hat_window(M, lnk, mean_dens):
@@ -191,30 +173,30 @@ def mass_to_radius(M, mean_dens):
             ``mean_dens``.
     """
     return (3.*M / (4.*np.pi * mean_dens)) ** (1. / 3.)
-#
-# def radius_to_mass(R, mean_dens):
-#     """
-#     Calculates mass of a region of space from its radius
-#
-#     Parameters
-#     ----------
-#     R : float or array of floats
-#         Radii
-#
-#     mean_dens : float
-#         The mean density of the universe
-#
-#     Returns
-#     ------
-#     M : float or array of floats
-#         The corresponding masses in R
-#
-#     Notes
-#     -----
-#     The units of ``R`` don't matter as long as they are consistent with
-#     ``mean_dens``.
-#     """
-#     return 4 * np.pi * R ** 3 * mean_dens / 3
+
+def radius_to_mass(R, mean_dens):
+    """
+    Calculates mass of a region of space from its radius
+
+    Parameters
+    ----------
+    R : float or array of floats
+        Radii
+
+    mean_dens : float
+        The mean density of the universe
+
+    Returns
+    ------
+    M : float or array of floats
+        The corresponding masses in R
+
+    Notes
+    -----
+    The units of ``R`` don't matter as long as they are consistent with
+    ``mean_dens``.
+    """
+    return 4 * np.pi * R ** 3 * mean_dens / 3
 
 def wdm_transfer(m_x, power_cdm, lnk, h, omegac):
     """
@@ -388,6 +370,7 @@ def get_hmf(required_attrs, get_label=True, **kwargs):
     Yield :class:`hmf.MassFunction` objects for all combinations of parameters supplied.
     """
     from hmf import MassFunction
+    import re
 
     order = ["delta_h", "delta_wrt", "delta_c", "user_fit", "mf_fit", "cut_fit",
              "z2", "nz", "z", "M", "wdm_mass", "sigma_8", "n", "lnk", "transfer_fit"][::-1]
@@ -415,17 +398,25 @@ def get_hmf(required_attrs, get_label=True, **kwargs):
     if not isinstance(required_attrs, (list, tuple)):
         attribute = required_attrs
     else:
-        attrs = ["ngtm", "mgtm", "mltm", "nltm", "how_big", "dndlnm", "dndlog10m", "dndm",
-             "sigma", "dlnsdlnm"]
-        for a in attrs:
+        attribute = "dndm"
+        mattrs = ["ngtm", "mgtm", "mltm", "nltm", "how_big", "dndlnm", "dndlog10m", "dndm",
+                 "fsigma", "n_eff", "lnsigma", "sigma", "_dlnsdlnm", "_sigma_0", "M"]
+        kattrs = ["nonlinear_power", "delta_k", "power", "transfer", "lnk",
+                   "_lnP_0", "_lnP_cdm_0", "_lnT_cdm", "_unnormalised_lnP",
+                   "_unnormalised_lnT"]
+        for a in mattrs + kattrs:
             if a in required_attrs:
                 attribute = a
+                break
 
     h = MassFunction(**kwargs)
 
     for vals in final_list:
         h.update(**vals)
-        getattr(h, attribute)
+        if attribute in mattrs:
+            getattr(h, attribute)
+        elif attribute in kattrs:
+            getattr(h.transfer, attribute)
         if get_label:
             if len(final_list) > 1:
                 label = str(vals)
@@ -434,9 +425,19 @@ def get_hmf(required_attrs, get_label=True, **kwargs):
             else:
                 label = h.mf_fit
 
-            label = label.replace("{", "").replace("}", "").replace("'", "").replace("_", "").replace(": ", "")
-            label = label.replace("mffit", "").replace("transferfit", "").replace("delta_wrt", "")
 
+            label = label.replace("{", "").replace("}", "").replace("'", "")
+            label = label.replace("_", "").replace(": ", "").replace(", ", "_")
+            label = label.replace("mffit", "").replace("transferfit", "").replace("delta_wrt", "").replace("\n", "")
+
+            # The following lines transform the M and lnk parts
+            while "[" in label:
+                label = re.sub("[\[].*?[\]]", "", label)
+            label = label.replace("array", "")
+            label = label.replace("M()", "M(" + str(np.log10(h.M[0])) + ", " + str(np.log10(h.M[-1])) + ", " +
+                          str(np.log10(h.M[1]) - np.log10(h.M[0])) + ")")
+            label = label.replace("lnk()", "lnk(" + str(h.transfer.lnk[0]) + ", " + str(h.transfer.lnk[-1]) + ", " +
+                          str(h.transfer.lnk[1] - h.transfer.lnk[0]) + ")")
             yield h, label
         else:
             yield h
